* 10SSIV.DO (RUNS SSIV REGRESSIONS)
* Ana Rute Cardoso w/ Louis-Philippe Morin
* Feb 2023
******************************************

cd "/Users/lpm/Library/CloudStorage/Dropbox/gender_LM_participation/LATEST_replication"
capture log close
log using "logs/10SSVI.log", replace nomsg

clear all
use "data/replic_stata_data/regs_cohortsiv_emig.dta", clear

global weights "wgt_emig50sLOO wgt_gap_panel_LOO wgt_gap_panel_LOO_ba1  wgt_gap_panel_LOO_ba2  wgt_gap_panel_LOO_ba3 wgt_tot_panel_LOO wgt_tot_panel_LOO_ba1  wgt_tot_panel_LOO_ba2  wgt_tot_panel_LOO_ba3"

gen emig=1

* LOO Weights
gen wgt_emig50sLOO=wgt_emig50s*(1-wgt_emig50s)
foreach i in "" _ba1 _ba2 _ba3 {
gen wgt_gap_panel_LOO`i'=wgt_emig50sLOO/(1.07*birth_inef`i')
gen wgt_tot_panel_LOO`i'=wgt_emig50sLOO/(birth_inef`i'+birth_inem`i')
}

* Saving Weights
 preserve
 keep cohort region wgt_emig50sLOO wgt_gap_panel_LO* wgt_tot_panel_LO*
 save "data/replic_stata_data/ss_Lshare_panel_LOO.dta", replace
 gen emig=1
 append using "data/replic_stata_data/ss_Lshare_panel_LOO.dta"
 replace emig=0 if emig==.
 replace wgt_emig50sLOO=1-wgt_emig50sLOO if emig==0
 foreach i in  wgt_gap_panel_LOO wgt_tot_panel_LOO {
 foreach j in "" _ba1 _ba2 _ba3 {	
 replace `i'`j'=1-`i'`j' if emig==0
 }
 }
 save "data/replic_stata_data/ss_Lshare_panel_LOO.dta", replace
 restore

* Number of Emigrants in France 
* SS using wgt_emig50s as weights
foreach i in "" _ba1 _ba2 _ba3 {
gen em_PT_f`i'=emf_leavo`i'/wgt_emig50sLOO
bys cohort: egen em_PT_f2`i'=max(em_PT_f`i')
gen em_PT_m`i'=emm_leavo`i'/wgt_emig50sLOO
bys cohort: egen em_PT_m2`i'=max(em_PT_m`i')
}

* Cohort-Level Shocks
foreach i in "" _ba1 _ba2 _ba3 {
gen em_gender_leavo_SS_c`i'=em_PT_m2`i'-1.07*em_PT_f2`i'
gen em_tot_leavo_SS_c`i'=em_PT_m2`i'+em_PT_f2`i'
}


* SS Data FLFP and Marriage
foreach i in $weights {
preserve
ssaggregate activratef evermarriedYNratef lR* lpopmf* [aw=popf], n(emig) t(cohort) s(`i') sfile("data/replic_stata_data/ss_Lshare_panel_LOO.dta") l(region) controls("educyrsf drregion_* dccohort_* `i' ")
save "data/replic_stata_data/transformed_data_SS_`i'.dta", replace
restore
}

append using "data/replic_stata_data/regs_cohortsiv_emig.dta"
replace emig=0 if emig==.

* Table F.15
preserve
keep cohort em_gender_leavo_SS_c em_tot_leavo_SS_c emig
collapse (mean) em_gender_leavo_SS_c em_tot_leavo_SS_c, by(cohort emig)
merge 1:1 cohort emig using "data/replic_stata_data/transformed_data_SS_wgt_gap_panel_LOO.dta"
* OLS
ivreg2 activratef lR lpopmf [aw=s_n] if emig==1, r
ivreg2 evermarriedYNratef lR lpopmf [aw=s_n] if emig==1, r
* IV Own Cohort
ivreg2 activratef (lR lpopmf = em_gender_leavo_SS_c em_tot_leavo_SS_c) [aw=s_n] if emig==1, r first
ivreg2 evermarriedYNratef (lR lpopmf = em_gender_leavo_SS_c em_tot_leavo_SS_c) [aw=s_n] if emig==1, r first
restore

* IV BA+-1 to BA+-3
forvalues i =1(1)3 {
preserve
keep cohort em_gender_leavo_SS_c_ba`i' em_tot_leavo_SS_c_ba`i' emig
collapse (mean) em_gender_leavo_SS_c_ba`i' em_tot_leavo_SS_c_ba`i', by(cohort emig)
merge 1:1 cohort emig using "data/replic_stata_data/transformed_data_SS_wgt_gap_panel_LOO_ba`i'.dta"
ivreg2 activratef (lR_ba`i' lpopmf_ba`i' = em_gender_leavo_SS_c_ba`i' em_tot_leavo_SS_c_ba`i') [aw=s_n] if emig==1, r first 
ivreg2 evermarriedYNratef (lR_ba`i' lpopmf_ba`i' = em_gender_leavo_SS_c_ba`i' em_tot_leavo_SS_c_ba`i') [aw=s_n] if emig==1, r first 
restore
}


* Table F.16
preserve
keep cohort em_gender_leavo_SS_c em_tot_leavo_SS_c emig
collapse (mean) em_gender_leavo_SS_c em_tot_leavo_SS_c, by(cohort emig)
merge 1:1 cohort emig using "data/replic_stata_data/transformed_data_SS_wgt_tot_panel_LOO.dta"
* OLS
ivreg2 activratef lR lpopmf [aw=s_n] if emig==1, r
ivreg2 evermarriedYNratef lR lpopmf [aw=s_n] if emig==1, r
* IV Own Cohort
ivreg2 activratef (lR lpopmf = em_gender_leavo_SS_c em_tot_leavo_SS_c) [aw=s_n] if emig==1, r first 
ivreg2 evermarriedYNratef (lR lpopmf = em_gender_leavo_SS_c em_tot_leavo_SS_c) [aw=s_n] if emig==1, r first 
restore

* IV BA+-1 to BA+-3
forvalues i =1(1)3 {
preserve
keep cohort em_gender_leavo_SS_c_ba`i' em_tot_leavo_SS_c_ba`i' emig
collapse (mean) em_gender_leavo_SS_c_ba`i' em_tot_leavo_SS_c_ba`i', by(cohort emig)
merge 1:1 cohort emig using "data/replic_stata_data/transformed_data_SS_wgt_tot_panel_LOO_ba`i'.dta"
ivreg2 activratef (lR_ba`i' lpopmf_ba`i' = em_gender_leavo_SS_c_ba`i' em_tot_leavo_SS_c_ba`i') [aw=s_n] if emig==1, r first 
ivreg2 evermarriedYNratef (lR_ba`i' lpopmf_ba`i' = em_gender_leavo_SS_c_ba`i' em_tot_leavo_SS_c_ba`i') [aw=s_n] if emig==1, r first 
restore
}
log close

