* 4b_read_educ_work_1950_1960.do
* read worksheet with education and work, census 1950 & 1960
* Ana Rute Cardoso & Louis-Philippe Morin
* Jul 2023
*****************************************************
clear all
capture program drop _all
version 16
capture log close
log using ..\replic_logs\4b_read_educ_work_1950_1960.log, replace nomsg

* 1950 

import excel using ..\replic_data\educ_work_census_1950_1960.xlsx, sheet(census1950) firstrow case(preserve) clear 
keep year distrito pop12plus1950 activ1950 agric1950 pop7plus1950 edliterate1950
save ..\_data\educ_work_by_district_1950.dta, replace

* 1960 

import excel using ..\replic_data\educ_work_census_1950_1960.xlsx, sheet(census1960) firstrow case(preserve) clear 
keep distrito year pop10plus1960 activ1960 agric1960 unemp1960 pop7plus1960 edliterate1960
save ..\_data\educ_work_by_district_1960.dta, replace

* allocate population from district to region

merge 1:1 distrito using ..\_data\educ_work_by_district_1950.dta
qui do codedistrict
joinby district using ..\_data\allocation_district_to_nuts3ipums.dta

foreach v in pop12plus1950 activ1950 agric1950 pop7plus1950 edliterate1950 pop10plus1960 activ1960 agric1960 unemp1960  {
   gen tmp`v' = `v' * alloc_dist_nuts
   bys nuts3ipums: egen `v'_region = total(tmp`v')
   replace `v'_region = round(`v'_region)
   drop `v'
}

bys nuts3ipums: keep if _n==1

* shares

gen activrate1950_region = activ1950_region / pop12plus1950_region
gen shagric1950_region = agric1950_region / activ1950_region
gen shliterate1950_region = edliterate1950_region / pop7plus1950_region

gen activrate1960_region = activ1960_region / pop10plus1960_region
gen shagric1960_region = agric1960_region / activ1960_region
gen urate1960_region = unemp1960_region / activ1960_region

* labels

label variable activrate1950    "activity rate, age 12+ (active pop. ('com profissao') / resident pop.), 1950"
label variable shagric1950      "share agriculture in active population, age 12+, 1950" 
label variable shliterate1950   "share literate population, age 7+, 1950" 

label variable activrate1960    "activity rate, age 10+ (active pop. ('com profissao') / resident pop.), 1960"
label variable shagric1960      "share agriculture in active population, age 10+, 1960" 
label variable urate1960        "unemployment rate, 1960"

* nuts3: harmonized variable "region"

gen region = 1000+real(nuts3ipums)  // short prefix 1 pt
qui do coderegion.do
label values region nuts3shortlb

keep region activrate1950 shagric1950 shliterate1950  activrate1960 shagric1960 urate1960 
save ..\_data\educ_work_by_region_1950_1960.dta, replace

log close
exit, clear