* 4e_FR_IPUMS.do
* build cells region-cohort
* Ana Rute Cardoso & Louis-Philippe Morin
* Jul 2023
************************************************

capture log close
clear
set scheme stgcolor
set more off, permanently
program drop _all
cd "/Users/lpm/Library/CloudStorage/Dropbox/gender_LM_participation/LATEST_replication"
global emig_graphs "graphs"
global source_data "data/replic_stata_data"
global work_data "data/replic_stata_data"
set type double
log using "logs/4e_FR_IPUMS.log", replace

************************
* Preparing Birth Data
************************

* The INE data are available in the replication folder
*Portugal
use "$source_data/births_pt_yr_dist_gender_1900_1980", clear
drop if district==99
rename male birth_inem
rename female birth_inef
rename year cohort
gen birth_ine_tot=birth_inem+birth_inef
collapse (sum) birth_ine_tot birth_inem birth_inef, by(cohort)
gen nation=43090
rename cohort birth_cohort
sort nation birth_cohort
save "$work_data/PT_Birth_Temp_replication.dta", replace
clear

* Spain
use "$source_data/births_es_yr_region_gender_1900_1985.dta", clear
gen birth_ine_tot=birth_inem+birth_inef
collapse (sum) birth_ine_tot birth_inem birth_inef, by(cohort)
gen nation=43120
rename cohort birth_cohort
sort nation birth_cohort
append using "$work_data/PT_Birth_Temp_replication.dta"
save "$work_data/ES_PT_Birth_Temp_replication.dta", replace
erase "$work_data/PT_Birth_Temp_replication.dta"
clear

************************
* Emigration Data
************************

*** The FR Census data are available through IPUMS International

foreach g in 1962 1968 1975 1982 1990 {
use "$source_data/France_IPUMS.dta" if year==`g', clear
gen emi_country="France"

gen birth_cohort=year-age-1

egen pop=sum(perwt)
format pop %12.0g
keep if (nation==43090 | nation==43120)

* Generating the Single (Never Married), Married, and Married with Absent Spouse Variables
gen single=(emarst==1)
gen spouse_abs=(sprule==0)
gen married=(emarst==2)
gen n_married=married*perwt
gen n_abs=spouse_abs*married*perwt

* Counting Individuals by Birth Year (Based on Age) Age, Sex, Marital Status and Country of Origin
collapse (sum) perwt n_married n_abs, by(birth_cohort year sex single nation emi_country)
forvalues i=0(1)1 {
forvalues j=1(1)2 {
gen n`i'`j'=perwt if single==`i' & sex==`j'
}
}

* Number of Currently Married, and Married with Absent Spouse by Sex
forvalues j=1(1)2 {
gen n_married`j'= n_married if sex==`j' & single==0
gen n_abs`j'= n_abs if sex==`j' & single==0
}

* Number of Ever Married and Singles by Year, Country and Birth Cohort
by year nation birth_cohort, sort: egen pf=min(n02)
replace pf=0 if pf==.
by year nation birth_cohort, sort: egen pm=min(n01)
replace pm=0 if pm==.
by year nation birth_cohort, sort: egen sf=min(n12)
replace sf=0 if sf==.
by year nation birth_cohort, sort: egen sm=min(n11)
replace sm=0 if sm==.

* Number of Currently Married with and without Absent Spouse by Year, Nationality and Birth Cohort
by year nation birth_cohort, sort: egen m_f=min(n_married2)
replace m_f=0 if m_f==.
by year nation birth_cohort, sort: egen m_m=min(n_married1)
replace m_m=0 if m_m==.
by year nation birth_cohort, sort: egen a_f=min(n_abs2)
replace a_f=0 if a_f==.
by year nation birth_cohort, sort: egen a_m=min(n_abs1)
replace a_m=0 if a_m==.

* Collapsing the Data to Get the Number of Individuals, Ever Married, Currently Married, Currently Married with Absent Spouse, and Singles
* by Birth Cohort, Census Year, Sex, and Nationality
collapse (sum) perwt (mean) pf pm sf sm m_f m_m a_f a_m, by(birth_cohort year sex nation emi_country)

gen female1=perwt if sex==2
gen male1=perwt if sex==1
by year nation birth_cohort, sort: egen malet=min(male1)
replace malet=0 if malet==.
by year nation birth_cohort, sort: egen femalet=min(female1)
replace femalet=0 if femalet==.
drop male1 female1
gen tot=malet+femalet

foreach i in s p {
gen male`i'=`i'm
gen female`i'=`i'f
gen tot`i'=`i'f + `i'm
}

by year nation birth_cohort, sort: gen obs=_N
drop if sex==2 & obs==2

keep year birth_cohort male* female* nation emi_country sf sm pf pm m_m m_f a_m a_f
foreach j in malet femalet males females malep femalep sf sm pf pm m_m m_f a_m a_f {
rename `j' `j'IA_FR_`g'
label variable `j'IA_FR_`g' "`j' in `g' FR (Cohort Based on Age)"

}
sort nation birth_cohort
save "$work_data/FR_IPUMS_Age_merge_`g'_replication.dta", replace
}

foreach g in 1962 1968 1975 1982 {
merge 1:1 nation birth_cohort using "$work_data/FR_IPUMS_Age_merge_`g'_replication.dta"
drop _merge
}

drop emi_country
foreach l in A {
foreach v in 1962 1968 1975 1982 1990 {
foreach g in malet femalet males females malep femalep sf sm pf pm  m_m m_f a_m a_f {
replace `g'I`l'_FR_`v'=0 if `g'I`l'_FR_`v'==.
}
}
}
sort nation birth_cohort year
save "$work_data/FR_IPUMS_merge_complete_replication.dta", replace

* Putting 0s for cohorts that are not observed in Census Years
foreach l in A {
foreach v in 1962 1968 1975 1982 1990 {
foreach g in malet femalet males females malep femalep sf sm pf pm {
replace `g'I`l'_FR_`v'=0 if `g'I`l'_FR_`v'==.
}
}
}

drop year
sort nation birth_cohort
save "$work_data/FR_IPUMS_merge_complete_replication.dta", replace
foreach g in 1962 1968 1975 1982 1990 {
erase "$work_data/FR_IPUMS_Age_merge_`g'_replication.dta"
}

* Merge with ES and PT Birth data
merge 1:1 nation birth_cohort using "$work_data/ES_PT_Birth_Temp_replication.dta"
sum birth_cohort if _merge==1
drop if _merge==1
sum birth_cohort if _merge==2
drop if _merge==2
drop _merge

save "$work_data/FR_IPUMS_merge_complete_replication.dta", replace
erase "$work_data/ES_PT_Birth_Temp_replication.dta"

*********
* Constructing Emigration Rates
*********

**** France

foreach t in 1962 1968 1975 1982 1990 {
foreach j in A {
* Emig Rate for Ever Married, Single and Total by Sex
foreach g in p s t {
gen male_emi_rate`g'I`j'_FR_`t'=100000*(male`g'I`j'_FR_`t'/birth_inem)
gen female_emi_rate`g'I`j'_FR_`t'=100000*(female`g'I`j'_FR_`t'/birth_inef)
gen tot_emit_rate`g'I`j'_FR_`t'=100000*((male`g'I`j'_FR_`t'+female`g'I`j'_FR_`t'))/birth_ine_tot
gen diff_emi_rate`g'I`j'_FR_`t'=male_emi_rate`g'I`j'_FR_`t'-female_emi_rate`g'I`j'_FR_`t'
}
* Emig Rate Currently Married and those with Absent Spouse by Sex
gen m_m_emi_rateI`j'_FR_`t'=100000*(m_mI`j'_FR_`t'/birth_inem)
gen m_f_emi_rateI`j'_FR_`t'=100000*(m_fI`j'_FR_`t'/birth_inef)
gen a_m_emi_rateI`j'_FR_`t'=100000*(a_mI`j'_FR_`t'/birth_inem)
gen a_f_emi_rateI`j'_FR_`t'=100000*(a_fI`j'_FR_`t'/birth_inef)
}

label variable female_emi_ratetIA_FR_`t' "Female Emigration Rate in `t' FR  (Cohort Based on Age)"
label variable male_emi_ratetIA_FR_`t' "Male Emigration Rate in `t' FR  (Cohort Based on Age)"
label variable tot_emit_ratetIA_FR_`t' "Total Emigration Rate in `t' FR  (Cohort Based on Age)"

label variable female_emi_ratepIA_FR_`t' "Married Female Emigration Rate in `t' FR  (Cohort Based on Age)"
label variable male_emi_ratepIA_FR_`t' "Married Male Emigration Rate in `t' FR  (Cohort Based on Age)"
label variable tot_emit_ratepIA_FR_`t' "Married Total Emigration Rate in `t' FR  (Cohort Based on Age)"


label variable female_emi_ratesIA_FR_`t' "Single Female Emigration Rate in `t' FR  (Cohort Based on Age)"
label variable male_emi_ratesIA_FR_`t' "Single Male Emigration Rate in `t' FR  (Cohort Based on Age)"
label variable tot_emit_ratesIA_FR_`t' "Single Total Emigration Rate in `t' FR  (Cohort Based on Age)"

}

preserve
keep *letIA_FR* birth_cohort nation
keep if nation==43090
keep *_1975 birth_cohort nation
save "$work_data/merged_Emig_INE_data_replication.dta", replace
restore

save "$work_data/merged_Emig_INE_data_complete_replication.dta", replace


******
*** Emigration Graphs
******

* Figure 4
twoway  (scatter male_emi_ratetIA_FR_1962 birth_cohort if nation==43090 & birth_cohort>1919  & birth_cohort<1961, sort ms(x) connect(l) lpattern(dot) xlabel(1920(5)1960) ylabel(0(5000)15000)) (scatter male_emi_ratetIA_FR_1968 birth_cohort if nation==43090 & birth_cohort>1919  & birth_cohort<1961, sort ms(square) msize(small) connect(l) lpattern(solid) xlabel(1920(5)1960) ylabel(0(5000)15000)) (scatter male_emi_ratetIA_FR_1975 birth_cohort if nation==43090 & birth_cohort>1919  & birth_cohort<1961, sort connect(l) lpattern(dash)  msize(small) xlabel(1920(5)1960) ylabel(0(5000)15000)) (scatter male_emi_ratetIA_FR_1982 birth_cohort if nation==43090 & birth_cohort>1919  & birth_cohort<1961, sort ms(D) msize(small) connect(l) lpattern(solid) xlabel(1920(5)1960) ylabel(0(5000)15000)) (scatter male_emi_ratetIA_FR_1990 birth_cohort if nation==43090 & birth_cohort>1919  & birth_cohort<1961, sort connect(l) ms(T) msize(small) lpattern(dash) xlabel(1920(5)1960) ylabel(0(5000)15000)), ytitle("Emigrants / 100,000 Births") xtitle(Birth Cohort) legend(order(1 "1962 Census" 2 "1968 Census" 3 "1975 Census" 4 "1982 Census" 5 "1990 Census") rows(2)) scheme(s1mono)
graph export "$emig_graphs/Cardoso-Figure-4.eps", replace
graph export "$emig_graphs/Cardoso-Figure-4.pdf", as(pdf) name("Graph") replace

* Figure B.1 (PT vs ES Male Emigration Measured in France)
twoway  (scatter male_emi_ratetIA_FR_1962 birth_cohort if nation==43090 & birth_cohort>1919  & birth_cohort<1961, sort ms(x) connect(l) lpattern(dot) xlabel(1920(5)1960) ylabel(0(5000)15000)) (scatter male_emi_ratetIA_FR_1968 birth_cohort if nation==43090 & birth_cohort>1919  & birth_cohort<1961, sort ms(square) msize(small) connect(l) lpattern(solid) xlabel(1920(5)1960) ylabel(0(5000)15000)) (scatter male_emi_ratetIA_FR_1975 birth_cohort if nation==43090 & birth_cohort>1919  & birth_cohort<1961, sort connect(l) lpattern(dash)  msize(small) xlabel(1920(5)1960) ylabel(0(5000)15000)) (scatter male_emi_ratetIA_FR_1962 birth_cohort if nation==43120 & birth_cohort>1919  & birth_cohort<1961, sort ms(x) connect(l) lpattern(dot) xlabel(1920(5)1960) ylabel(0(5000)15000)) (scatter male_emi_ratetIA_FR_1968 birth_cohort if nation==43120 & birth_cohort>1919  & birth_cohort<1961, sort ms(square) msize(small) connect(l) lpattern(solid) xlabel(1920(5)1960) ylabel(0(5000)15000)) (scatter male_emi_ratetIA_FR_1975 birth_cohort if nation==43120 & birth_cohort>1919  & birth_cohort<1961, sort connect(l) lpattern(dash)  msize(small) xlabel(1920(5)1960) ylabel(0(5000)15000)), ytitle("Emigrants / 100,000 Births") xtitle(Birth Year) legend(position(6) order(1 "PT 1962 Census" 2 "PT 1968 Census" 3 "PT 1975 Census" 4 "ES 1962 Census" 5 "ES 1968 Census" 6 "ES 1975 Census") rows(2)) scheme(s2color)
graph export "$emig_graphs/Cardoso-Figure-B1.eps", replace
graph export "$emig_graphs/Cardoso-Figure-B1.pdf", as(pdf) name("Graph") replace

* Figure B.2a (Married Male Emigration Measured in France)
twoway  (scatter m_m_emi_rateIA_FR_1968 birth_cohort if nation==43090 & birth_cohort>1919  & birth_cohort<1961, sort ms(square)  msize(small) connect(l) lpattern(dash) xlabel(1920(5)1960) ylabel(0(5000)15000)) (scatter m_m_emi_rateIA_FR_1975 birth_cohort if nation==43090 & birth_cohort>1919  & birth_cohort<1961, sort connect(l)  msize(small) lpattern(dash) xlabel(1920(5)1960) ylabel(0(5000)15000)) (scatter male_emi_ratetIA_FR_1968 birth_cohort if nation==43090 & birth_cohort>1919  & birth_cohort<1961, sort ms(square) msize(small) connect(l) lpattern(solid) xlabel(1920(5)1960) ylabel(0(5000)15000)) (scatter male_emi_ratetIA_FR_1975 birth_cohort if nation==43090 & birth_cohort>1919  & birth_cohort<1961, sort connect(l) msize(small) lpattern(solid) xlabel(1920(5)1960) ylabel(0(5000)15000)), ytitle("Emigrants / 100,000 Births") xtitle(Birth Year) legend(order(1 "1968 Married Male Emig." 2 "1975 Married Male Emig." 3 "1968 Total Male Emig." 4 "1975 Total Male Emig.")) scheme(s2color)
graph export "$emig_graphs/Cardoso-Figure-B2a.eps", replace
graph export "$emig_graphs/Cardoso-Figure-B2a.pdf", as(pdf) name("Graph") replace

* Figure B.2b (Married Female Emigration Measured in France)
twoway  (scatter m_f_emi_rateIA_FR_1968 birth_cohort if nation==43090 & birth_cohort>1919  & birth_cohort<1961, sort ms(square)  msize(small) connect(l) lpattern(dash) xlabel(1920(5)1960) ylabel(0(5000)15000)) (scatter m_f_emi_rateIA_FR_1975 birth_cohort if nation==43090 & birth_cohort>1919  & birth_cohort<1961, sort connect(l)  msize(small) lpattern(dash) xlabel(1920(5)1960) ylabel(0(5000)15000)) (scatter female_emi_ratetIA_FR_1968 birth_cohort if nation==43090 & birth_cohort>1919  & birth_cohort<1961, sort ms(square) msize(small) connect(l) lpattern(solid) xlabel(1920(5)1960) ylabel(0(5000)15000)) (scatter female_emi_ratetIA_FR_1975 birth_cohort if nation==43090 & birth_cohort>1919  & birth_cohort<1961, sort connect(l) msize(small) lpattern(solid) xlabel(1920(5)1960) ylabel(0(5000)15000)), ytitle("Emigrants / 100,000 Births") xtitle(Birth Year) legend(order(1 "1968 Married Female Emig." 2 "1975 Married Female Emig." 3 "1968 Total Female Emig." 4 "1975 Total Female Emig.")) scheme(s2color)
graph export "$emig_graphs/Cardoso-Figure-B2b.eps", replace
graph export "$emig_graphs/Cardoso-Figure-B2b.pdf", as(pdf) name("Graph") replace


* Figure B.3 (Female and Male PT Emigration Measured in France)
twoway  (scatter female_emi_ratetIA_FR_1962 birth_cohort if nation==43090 & birth_cohort>1919  & birth_cohort<1961, sort ms(circle) msize(small) connect(l) lpattern(solid) xlabel(1920(5)1960) ylabel(0(5000)15000)) (scatter female_emi_ratetIA_FR_1968 birth_cohort if nation==43090 & birth_cohort>1919  & birth_cohort<1961, sort ms(square) msize(small) connect(l) lpattern(solid) xlabel(1920(5)1960) ylabel(0(5000)15000)) (scatter female_emi_ratetIA_FR_1975 birth_cohort if nation==43090 & birth_cohort>1919  & birth_cohort<1961, sort ms(triangle) msize(small) connect(l) lpattern(dash) xlabel(1920(5)1960) ylabel(0(5000)15000)) (scatter male_emi_ratetIA_FR_1962 birth_cohort if nation==43090 & birth_cohort>1919  & birth_cohort<1961, sort ms(square) msize(small) connect(l) lpattern(dot) xlabel(1920(5)1960) ylabel(0(5000)15000)) (scatter male_emi_ratetIA_FR_1968 birth_cohort if nation==43090 & birth_cohort>1919  & birth_cohort<1961, sort ms(square) msize(small) connect(l) lpattern(dot) xlabel(1920(5)1960) ylabel(0(5000)15000)) (scatter male_emi_ratetIA_FR_1975 birth_cohort if nation==43090 & birth_cohort>1919  & birth_cohort<1961, sort ms(triangle) msize(small) connect(l) lpattern(shortdash) xlabel(1920(5)1960) ylabel(0(5000)15000)),  ytitle("Emigrants / 100,000 Births") xtitle(Birth Year) legend(order(1 "1962 Female" 2 "1968 Female" 3 "1975 Female" 4 "1962 Male" 5 "1968 Male" 6 "1975 Male") rows(2)) scheme(s2color)
graph export "$emig_graphs/Cardoso-Figure-B3.eps", replace
graph export "$emig_graphs/Cardoso-Figure-B3.pdf", as(pdf) name("Graph") replace

log close
