* 6cells.do
* build cells region-cohort
* Ana Rute Cardoso & Louis-Philippe Morin
* Jul 2023
************************************************
clear all
capture program drop _all
version 16
capture log close
log using ..\replic_logs\6cells.log, replace nomsg

*** census ipums

use c:\Ana_orig_censusIPUMS\IPUMS_portugal_census_1981_1991_2001_2011_DATA_ORIG.dta if year==1981, clear

* birth cohort // not reported in census portugal; reported age as of census date 16mar81

gen cohort = year-age-1

* nuts3: short coding of residence (prefix 1 portugal), drop islands

gen nuts3resid = enuts3 
recode nuts3resid 22111=1111 22112=1112 22113=1113 22114=1114 22115=1115 22116=1116 22117=1117 ///
       22118=1118 22150=1150 22161=1161 22162=1162 22163=1163 22169=1169 22165=1165 22166=1166 ///
       22167=1167 22171=1171 22172=1172 22185=1185 22189=1189 22200=1200 22300=1300 2299997=888888

qui do coderegion.do
label values nuts3resid nuts3shortlb
drop if nuts3resid >=1200

* recode "not in universe", "not applicable", and similar into missing

recode empstat 0 9 =.
recode edattaind 0 999=.
recode occisco 97 98 99=.

keep     year perwt age cohort sex nuts3resid empstat occisco edattaind emarst age_sp sex_sp nchild
order    year perwt age cohort sex nuts3resid empstat occisco edattaind emarst age_sp sex_sp nchild
compress year perwt age cohort sex nuts3resid empstat occisco edattaind emarst age_sp sex_sp nchild
save ..\_data\census_key_vars.dta, replace

*** prepare cells census

gen m=(sex==1)
gen f=(sex==2)

* education: population, in employment

gen educyrs=edattaind
recode educyrs 100=0 130=4 212=6 221=9 311/322=12 400=15
gen Cempeducyrs = educyrs if empstat==1

* occupation 

gen     occiscogood = 1 if occisco==1 & empstat==1
replace occiscogood = 0 if occiscogood==. & occisco!=. & empstat==1
label variable occiscogood "occisco=1 (senior officials,managers,legislators)"

gen     occisco6 = 1 if occisco==6 & empstat==1
replace occisco6 = 0 if occisco6==. & occisco!=. & empstat==1
label variable occisco6 "occisco=6 (agric, forestry, fishermen, hunters)"

* by gender

foreach g in m f {
   * work

   gen   emp`g' = 1 if empstat==1 & `g'==1
   gen unemp`g' = 1 if empstat==2 & `g'==1
   gen activ`g' = 1 if (empstat==1 | empstat==2) & `g'==1

   foreach v in emp unemp activ { 
      replace `v'`g'=0 if `v'`g'==. & empstat!=. & `g'==1
   }

   gen     occiscogood`g' = 1 if occiscogood==1 & `g'==1
   replace occiscogood`g' = 0 if occiscogood==0 & `g'==1
   label variable occiscogood`g' "=1 if occisco=1 (senior offs.,managers,legislat.) & gender=`g'"

   gen     occisco6`g' = 1 if occisco6==1 & `g'==1
   replace occisco6`g' = 0 if occisco6==0 & `g'==1
   label variable occisco6`g' "=1 if occisco=6 (agric,forest,fisher,hunters) & gender=`g'"
        
   * education

   gen educyrs`g'=educyrs if `g'==1 
   gen Cempeducyrs`g'=Cempeducyrs if `g'==1 

   * ever married, separated

   gen evermarriedYN`g'=1 if (emarst==2 | emarst==3 | emarst==4) & `g'==1
   gen separatedYN`g'=1 if emarst==4 & `g'==1

   foreach v in evermarriedYN  separatedYN  { 
      replace `v'`g'=0 if `v'`g'==. & emarst!=. & `g'==1
   }

   label variable evermarriedYN`g' "ever married (now married or union, separat or divorc, widow), `g'"
   label variable separatedYN`g' "separated or divorced, `g'"

   * nb children 

   gen nchild`g'=nchild if `g'==1
}

keep year perwt age cohort m f nuts3resid activ* emp* unemp* occisco*  /// 
     educyrs* Cempeducyrs* evermarriedYN* separated* nchild*
save ..\_data\census_incl_dummies.dta, replace

*** read QP

use ano idemp gender datanasc sitprof contrem educ wbase wregul hnorm /// 
    using c:\Ana_orig\data_stata_ok\ISCOtrab1985.dta, clear

merge m:1 idemp using c:\Ana_orig\data_stata_ok\empresa1985.dta, keepusing(nutsm3) keep(3)

* cohort, replicate computation in census: age as of census date; then cohort=year-age-1

gen birthmonth = datanasc-(int(datanasc/100))*100
gen birthyear = int(datanasc/100)
gen birthddate = mdy(birthmonth,01,birthyear)
gen datecensus81 = mdy(03,16,1981)

personage birthddate datecensus81, gen(age)

gen cohort = 1981-age-1
drop if cohort==.

* keep relevant set: mainland; w-earners

gen region = nutsm3
recode region 111=1111 112=1112 113=1113 114=1114 115=1115 116=1116 117=1117      ///
              118=1118 150=1150 1610=1161 1620=1162 1630=1163 1650=1165 1692=1166 ///
              1693=1167 1640 1660/1691=1169 171=1171 172=1172 185=1185 181/184=1189  *=. 

qui do coderegion.do
label values region nuts3shortlb
drop if region==.

keep if sitprof==3 
keep if wbase!=. & wbase!=0
keep if contrem==0 | contrem==1

*** prepare cells QP

gen m=(gender==0)
gen f=(gender==1)

ren educ qpeducyrs

gen wh = (wbase+wregul)/hnorm

run deflate_PT2012.ado
qui deflatePT2012 wh ano
gen rwh=exp(lrwh)

* drop w outliers

qui sum rwh, detail
gen woutlier=1 if (rwh>10*r(p99) & rwh~=.) | rwh<0.5*r(p1)
replace lrwh=. if woutlier==1
replace rwh=.  if woutlier==1

* by gender

foreach g in m f {
   * empl

   gen qpemp`g' = 1 if `g'==1
   replace qpemp`g'=0 if `g'!=1

   * hourly wages

   gen lrwh`g'=lrwh if `g'==1

   * educ

   gen qpeducyrs`g'=qpeducyrs if `g'==1
}

gen year=1981
label variable year "year in Census for the matching (QP march85 matched to Census march81)"

keep     year cohort region qpemp* qped* lrwh*
order    year cohort region qpemp* qped* lrwh*
compress year cohort region qpemp* qped* lrwh*
save ..\_data\qp_incl_dummies.dta, replace

*** census cells, collapsed by region-cohort

use ..\_data\census_incl_dummies.dta, clear

gen long region=nuts3resid

collapse (sum) popm=m popf=f                                            ///
               empm empf unempm unempf activm activf                    ///
               occisco*m occisco*f                                      ///
	       evermarriedYNm evermarriedYNf separatedYNm separatedYNf  ///
               nchildm nchildf                                          ///
        (mean) educyrsm educyrsf Cempeducyrsm Cempeducyrsf              ///
               age [fweight=perwt], by(year cohort region) fast
save ..\_data\tmp_cells_residencecensus_year_cohortregion.dta, replace

*** QP cells, collapsed by region-cohort

use ..\_data\qp_incl_dummies.dta, clear

collapse (sum) qpempm qpempf                      ///
        (mean) qpeducyrsm qpeducyrsf lrwhm lrwhf  /// 
        , by(year cohort region) fast
save ..\_data\tmp_cells_qp_year_cohortregion.dta, replace

*** INE births

use cohort region birth_inem birth_inef using ..\_data\births_pt_yr_region_gender_1927_1980.dta, clear
collapse (sum) birth_inem birth_inef, by(cohort region) fast  // zero if no birth
save ..\_data\tmp_cells_birthine_cohortregion.dta, replace

*** emigration by region in portugal

use decade region Nemig_legal_region wgt_emig_in_mainland using ..\_data\emig_legal_by_region_50s_60s_70s_80s.dta, clear
ren Nemig_legal_region Nemig
ren wgt_emig_in_mainland wgt_emig

reshape wide Nemig wgt_emig, i(region) j(decade) string

foreach d in 50s 60s 70s 80s {
   egen tot`d'=total(wgt_emig`d')
   label variable Nemig`d' "legal emigration in 19`d'"
   label variable wgt_emig`d' "share of region in mainland legal emigration 19`d'"
}

keep region Nemig50s Nemig60s wgt_emig50s wgt_emig60s
save ..\_data\weights_emig_region_50s_60s.dta, replace

*** immigration by cohort and gender in france

use ..\_data\merged_Emig_INE_data_replication.dta, clear
assert nation==43090

ren maletIA_FR_1975   m_imigFR
ren femaletIA_FR_1975 f_imigFR
ren birth_cohort cohort

keep cohort m_imigFR f_imigFR
save ..\_data\immigrationFR_fromPT.dta, replace

*** merge cells from different sources

use ..\_data\tmp_cells_residencecensus_year_cohortregion.dta, clear
merge 1:1 year cohort region using ..\_data\tmp_cells_qp_year_cohortregion.dta
assert _merge!=2
gen inqp=1 if _merge==3
drop _merge

merge m:1 cohort region using ..\_data\tmp_cells_birthine_cohortregion.dta
drop _merge

merge m:1 region using ..\_data\weights_emig_region_50s_60s.dta
drop _merge

merge m:1 region using ..\_data\educ_work_by_region_1950_1960.dta, keepusing(activrate1960 shagric1960 urate1960)
drop _merge

merge m:1 region using ..\_data\milit_recruit_delinq_by_region_1968.dta
drop _merge 

merge m:1 cohort using ..\_data\immigrationFR_fromPT.dta
assert _merge!=2

*** compute sums and rates

foreach v in pop birth_ine emp qpemp { 
   gen `v'mf = `v'm+`v'f
}

foreach v in activ emp evermarriedYN nchild {
foreach g in m f {
   gen `v'rate`g' = `v'`g'/pop`g'
   label variable `v'rate`g' "`v' rate for `g' (over population)"
}
}

foreach g in m f {
   gen urate`g' = unemp`g' / activ`g'
   label variable urate`g' "unemployment rate `g' (over active population `g')"
}

gen separYNf_ratemar = separatedYNf / evermarriedYNf
label variable separYNf_ratemar "separation rate for f (over ever married)"
  
*** compute gaps

* work, educ

foreach v in lrwh activrate educyrs Cempeducyrs  { 
   gen gap_`v' = `v'm - `v'f
   label variable gap_`v' "gap: `v' M - `v'F"
} 

* marriage

gen gap_evermarried_rate = evermarriedYNratem - evermarriedYNratef
label variable gap_evermarried_rate "gap: rate ever married, M - F"

* share of females in good occupations (over total jobs in good occupations)

gen shf_ingoodoccisco = occiscogoodf / (occiscogoodf + occiscogoodm)
label variable shf_ingoodoccisco "share females in good occisco (over total jobs in good occup)"

gen shf_in6occisco = occisco6f / (occisco6f + occisco6m)
label variable shf_in6occisco "share females in occisco 6 (over total jobs in occup=6)"

* gap in share of females in good occupations (over total population) 

gen shf_ingoodoccisco_pop_gap = (occiscogoodm / popm) - (occiscogoodf/popf)
label variable shf_ingoodoccisco_pop_gap "gap in shareM - shareF in good occisco (over total pop M or F)"

* sex ratios: at birth; for population

gen Rbirth = birth_inem / birth_inef
gen R = popm / popf

label variable Rbirth "sex ratio M/F at birth"
label variable R "sex ratio M/F population at census year"

*** instruments emigration

* Nemig total

foreach g in m f {
   gen em`g' = `g'_imigFR * wgt_emig50s
   label variable em`g' "Nemig `g', allocated to regions using emig50s"
}
gen emmf = (emm + emf)
label variable emmf "Nemig m+f, allocated to regions using emig50s"

* Nemig leave-out own region
 
foreach g in m f mf {
   gen em`g'_leavo = em`g' * (1- wgt_emig50s)
   label variable em`g'_leavo "leave-own-out Nemig `g', allocated to regions using emig50s"
}
 
* rate emig
   
foreach g in m f mf {
   gen em`g'_rate_leavo = em`g'_leavo / birth_ine`g'
   label variable em`g'_rate_leavo "leave-own-out emig rate `g' (over birth coh), allocated to regions using emig50s"
}

* gender composition emig

gen em_gender_leavo = emm_rate_leavo - emf_rate_leavo
label variable em_gender_leavo "(emig/births)m - (emig/births)f, allocated to regions using emig50s"

*** instruments draft delinquency

gen shregistered1968 = registered1968 / birthsm1948
label variable shregistered1968 "males in military census / births, cohort 1948"

*** additional labels

foreach g in m f mf {
   label variable birth_ine`g' "N births, `g'"
   label variable pop`g' "population, `g'"
   label variable emp`g' "N employed Census, `g'"
   label variable qpemp`g' "N employed QP, `g'"
}

foreach g in m f {
   label variable unemp`g' "N unemployed, `g'"
   label variable activ`g' "N active, `g'"
}
label variable region "nuts3, recoded harmonized ipums and qp"
label values region nuts3shortlb

*** save file

keep year cohort age region Rbirth R popm popf popmf birth_inem birth_inef birth_inemf ///
     evermarriedYNrate* gap_evermarried_rate separYNf_ratemar nchildratef              ///
     activrate* gap_activrate empm empf empmf emprate* urate*                          /// 
     shf_ingoodoccisco  shf_in6occisco shf_ingoodoccisco_pop_gap                       ///  
     qpempm qpempf qpempmf lrwhm lrwhf gap_lrwh                                        /// 
     educyrs* gap_educyrs Cempeducyrs* gap_Cempeducyrs qpeducyrs*                      ///
     wgt_emig50s em*_leavo em*_rate_leavo  em_gender_leavo                             ///
     activrate1960 shagric1960 urate1960                                               /// 
     shregistered1968 shdelinq1968 wgt_delinq1968 
save ..\_data\cells_year_cohortregion.dta, replace

*** change in sex ratio, all cohorts together within each region

use year region cohort birth_inem birth_inef popm popf using ..\_data\cells_year_cohortregion.dta, clear
keep if cohort>=1937 & cohort<=1954

bys region: egen birth_m = total(birth_inem)
bys region: egen birth_f = total(birth_inef)
bys region: egen pop_m = total(popm)
bys region: egen pop_f = total(popf)

bys region: keep if _n==1

gen Rbirth = birth_m / birth_f
gen Rpop = pop_m / pop_f
gen Rchange = Rpop - Rbirth

keep year region birth_m birth_f pop_m pop_f Rbirth Rpop Rchange
save ..\_data\change_R.dta, replace

log close
exit, clear