* 8occups.do
* define "blue / pink" occupations in 1960 census
* Ana Rute Cardoso & Louis-Philippe Morin
* Jul 2023
******************************************
clear all
capture program drop _all
version 16
capture log close
log using ..\replic_logs\8occups.log, replace nomsg

*** read 1960 census excel data on active population by occupations male/female

import excel using ..\replic_data\occups_empl_census_1960.xlsx, sheet(occ1960pt_stata) firstrow case(preserve) clear 

* collapse into 1-digit ipums classification, occisco

keep if IPUMS_occ1981!="" // only 2-digit categories were assigned an ipums occisco and occ1981 code, to avoid double counting obs
collapse (sum) mactive factive, by(occisco)
destring occisco, replace

* label occupation IPUMS occisco

#delimit ;
label define occisco_lbl                                 
           1 "Legislators, senior officials and managers"
           2 "Professionals"
           3 "Technicians and associate professionals"
           4 "Clerks"
           5 "Service workers and shop and market sales"
           6 "Skilled agricultural and fishery workers"
           7 "Crafts and related trades workers"
           8 "Plant and machine operators and assemblers"
           9 "Elementary occupations"
          10 "Armed forces"
          11 "Other occupations, unspecified or n.e.c."
          97 "Response suppressed"
          98 "Unknown"
          99 "NIU (not in universe)";
#delimit cr
label values occisco occisco_lbl
drop if occisco>=11 

*** "pink" or "blue" occupations in PT census 1960: incidence at least double the other gender

foreach g in m f {
	egen tot`g'=total(`g')
	gen occisco_incid`g'60 = `g'/tot`g'
}

gen     occisco_color60=1  if occisco_incidm/occisco_incidf >=2  
replace occisco_color60=2  if occisco_incidm/occisco_incidf <=.5    
replace occisco_color60=12 if occisco_incidm/occisco_incidf >.5 & occisco_incidm/occisco_incidf < 2 

label define occiscocolor_lbl 1 "blue" 2 "pink" 12 "mixed"
label values occisco_color60 occiscocolor_lbl 

gen year=1960
keep year occisco mactive factive occisco_color60
save ..\_data\occisco_blue_pink_census1960.dta, replace

*** append to 1981 census data on active population
          
use year perwt sex occisco empstat using ..\_data\census_key_vars.dta, clear
drop if occisco==. // inactive 

gen m=(sex==1)
gen f=(sex==2)

foreach g in m f {
	gen `g'active = 1 if (empstat==1 | empstat==2) & `g'==1
	replace `g'active=0 if `g'active==. & empstat!=. & `g'==1
}

keep  year perwt occisco mactive factive
collapse (sum) mactive factive  [fweight=perwt], by(year occisco) fast
append using ..\_data\occisco_blue_pink_census1960.dta

*** relative incidence of each occupation, by year

foreach g in m f {
	bys year: egen tot`g'=total(`g')
	gen occisco_incid`g' = `g'/tot`g'
}
gen occisco_incidrel = occisco_incidm / occisco_incidf

ren occisco_color60 tmpoccisco_color60
bys occisco: egen occisco_color60 = mean(tmpoccisco_color60)
label values occisco_color60 occiscocolor_lbl 

label variable occisco_color60 "blue(pink) occup: at least double incidence among males(female) 1960 PT census"
label variable occisco_incidm "occ. incidence among males (Moccup/Mtot), by year"
label variable occisco_incidf "occ. incidence among females (Foccup/Ftot), by year"
label variable occisco_incidrel "occ. incidence M/F, by year"

keep year occisco occisco_color60 occisco_incidm occisco_incidf occisco_incidrel
save ..\_data\occisco_blue_pink_census_60_81.dta, replace

*** Table 4

sort year occisco
list year occisco occisco_color60  occisco_incidm occisco_incidf occisco_incidrel, noobs sepby(year) str(20)

log close
exit, clear
